==> libro-codemirror-0.1.0.tgz: package/es/tooltip.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
/* eslint-disable @typescript-eslint/no-parameter-properties */
/* eslint-disable @typescript-eslint/parameter-properties */
import { StateEffect, StateField } from '@codemirror/state';
import { ViewPlugin, showTooltip, EditorView } from '@codemirror/view';
import { defaultSanitizer } from '@difizen/libro-common';
import { renderText } from '@difizen/libro-rendermime';
export var startTooltipEffect = StateEffect.define();
export var closeTooltipEffect = StateEffect.define();
var tooltipResultEffect = StateEffect.define({});
var getCursorTooltips = function getCursorTooltips(state, text) {
  return {
    pos: state.selection.main.head,
    above: false,
    strictSide: false,
    arrow: false,
    create: function create() {
      var dom = document.createElement('div');
      dom.className = 'cm-tooltip-libro';
      renderText({
        sanitizer: defaultSanitizer,
        source: text,
        host: dom,
        mimeType: ''
      });
      return {
        dom: dom
      };
    }
  };
};
var tooltipField = StateField.define({
  create: function create() {
    return null;
  },
  update: function update(_tooltips, tr) {
    var effects = tr.effects;
    var _iterator = _createForOfIteratorHelper(effects),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var effect = _step.value;
        if (effect.is(closeTooltipEffect)) {
          return null;
        } else if (effect.is(tooltipResultEffect)) {
          var text = effect.value.tooltipText;
          if (text !== null) {
            return getCursorTooltips(tr.state, text);
          }
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return null;
  },
  provide: function provide(f) {
    return showTooltip.compute([f], function (state) {
      var filed = state.field(f);
      if (filed === null) {
        return null;
      }
      return filed;
    });
  }
});

/// Explicitly start tooltip.
export var startTooltip = function startTooltip(view) {
  view.dispatch({
    effects: startTooltipEffect.of(true)
  });
  return true;
};

/// Close tooltip.
export var closeTooltip = function closeTooltip(view) {
  view.dispatch({
    effects: closeTooltipEffect.of(null)
  });
  return true;
};
export var tooltipKeymap = [{
  key: 'Shift-Tab',
  run: startTooltip
}, {
  key: 'Escape',
  run: closeTooltip
}];
var cursorTooltipBaseTheme = EditorView.baseTheme({
  '.cm-tooltip.cm-tooltip-libro': {
    zIndex: '10001',
    color: 'rgba(0,0,0,0.87)',
    padding: '2px 7px',
    borderRadius: '4px',
    boxShadow: 'rgba(0,0,0,0.2) 0px 3px 5px -1px, rgba(0,0,0,0.0.14) 0px 6px 10px 0px, rgba(0,0,0,0.0.12) 0px 1px 18px 0px',
    maxHeight: '350px',
    overflow: 'auto'
  }
});
var TooltipPlugin = /*#__PURE__*/function () {
  function TooltipPlugin(view, tooltipProvider) {
    _classCallCheck(this, TooltipPlugin);
    this.view = view;
    this.tooltipProvider = tooltipProvider;
  }
  _createClass(TooltipPlugin, [{
    key: "update",
    value: function update(_update) {
      var _this = this;
      _update.transactions.forEach(function (tr) {
        var _iterator2 = _createForOfIteratorHelper(tr.effects),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var effect = _step2.value;
            if (effect.is(startTooltipEffect) && _this.tooltipProvider) {
              _this.tooltipProvider({
                cursorPosition: _update.view.state.selection.main.anchor
              }).then(function (result) {
                _update.view.dispatch({
                  effects: tooltipResultEffect.of({
                    tooltipText: result
                  })
                });
                return undefined;
              }).catch(function () {
                //
              });
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      });
    }
  }]);
  return TooltipPlugin;
}();
var asyncShowTooltip = function asyncShowTooltip(tooltipProvider) {
  return ViewPlugin.define(function (view) {
    return new TooltipPlugin(view, tooltipProvider);
  }, {
    eventHandlers: {
      blur: function blur() {
        var state = this.view.state.field(tooltipField, false);
        if (state) {
          this.view.dispatch({
            effects: closeTooltipEffect.of(null)
          });
        }
      }
    }
  });
};
export function tabTooltip(tooltipProvider) {
  return [tooltipField, cursorTooltipBaseTheme, asyncShowTooltip(tooltipProvider)];
}

==> libro-codemirror-0.1.7.tgz: package/es/tooltip.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
/* eslint-disable @typescript-eslint/no-parameter-properties */
/* eslint-disable @typescript-eslint/parameter-properties */
import { StateEffect, StateField } from '@codemirror/state';
import { ViewPlugin, showTooltip, EditorView } from '@codemirror/view';
import { defaultSanitizer } from '@difizen/libro-common';
import { renderText } from '@difizen/libro-rendermime';
export var startTooltipEffect = StateEffect.define();
export var closeTooltipEffect = StateEffect.define();
var tooltipResultEffect = StateEffect.define({});
var getCursorTooltips = function getCursorTooltips(state, text) {
  return {
    pos: state.selection.main.head,
    above: false,
    strictSide: false,
    arrow: false,
    create: function create() {
      var dom = document.createElement('div');
      dom.className = 'cm-tooltip-libro';
      renderText({
        sanitizer: defaultSanitizer,
        source: text,
        host: dom,
        mimeType: ''
      });
      return {
        dom: dom
      };
    }
  };
};
var tooltipField = StateField.define({
  create: function create() {
    return null;
  },
  update: function update(tooltips, tr) {
    var effects = tr.effects;
    var _iterator = _createForOfIteratorHelper(effects),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var effect = _step.value;
        if (effect.is(closeTooltipEffect)) {
          return null;
        } else if (effect.is(tooltipResultEffect)) {
          var text = effect.value.tooltipText;
          if (text !== null) {
            return getCursorTooltips(tr.state, text);
          }
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return null;
  },
  provide: function provide(f) {
    return showTooltip.compute([f], function (state) {
      var filed = state.field(f);
      if (filed === null) {
        return null;
      }
      return filed;
    });
  }
});

/// Explicitly start tooltip.
export var startTooltip = function startTooltip(view) {
  view.dispatch({
    effects: startTooltipEffect.of(true)
  });
  return true;
};

/// Close tooltip.
export var closeTooltip = function closeTooltip(view) {
  view.dispatch({
    effects: closeTooltipEffect.of(null)
  });
  return true;
};
export var tooltipKeymap = [{
  key: 'Shift-Tab',
  run: startTooltip
}, {
  key: 'Escape',
  run: closeTooltip
}];
var cursorTooltipBaseTheme = EditorView.baseTheme({
  '.cm-tooltip.cm-tooltip-libro': {
    zIndex: '10001',
    color: 'rgba(0,0,0,0.87)',
    padding: '2px 7px',
    borderRadius: '4px',
    boxShadow: 'rgba(0,0,0,0.2) 0px 3px 5px -1px, rgba(0,0,0,0.0.14) 0px 6px 10px 0px, rgba(0,0,0,0.0.12) 0px 1px 18px 0px',
    maxHeight: '350px',
    overflow: 'auto'
  }
});
var TooltipPlugin = /*#__PURE__*/function () {
  function TooltipPlugin(view, tooltipProvider) {
    _classCallCheck(this, TooltipPlugin);
    this.view = view;
    this.tooltipProvider = tooltipProvider;
  }
  _createClass(TooltipPlugin, [{
    key: "update",
    value: function update(_update) {
      var _this = this;
      _update.transactions.forEach(function (tr) {
        var _iterator2 = _createForOfIteratorHelper(tr.effects),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var effect = _step2.value;
            if (effect.is(startTooltipEffect) && _this.tooltipProvider) {
              _this.tooltipProvider({
                cursorPosition: _update.view.state.selection.main.anchor
              }).then(function (result) {
                _update.view.dispatch({
                  effects: tooltipResultEffect.of({
                    tooltipText: result
                  })
                });
                return undefined;
              }).catch(console.error);
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      });
    }
  }]);
  return TooltipPlugin;
}();
var asyncShowTooltip = function asyncShowTooltip(tooltipProvider) {
  return ViewPlugin.define(function (view) {
    return new TooltipPlugin(view, tooltipProvider);
  }, {
    eventHandlers: {
      blur: function blur() {
        var state = this.view.state.field(tooltipField, false);
        if (state) {
          this.view.dispatch({
            effects: closeTooltipEffect.of(null)
          });
        }
      }
    }
  });
};
export function tabTooltip(tooltipProvider) {
  return [tooltipField, cursorTooltipBaseTheme, asyncShowTooltip(tooltipProvider)];
}
